@@ -4,6 +4,8 @@ from .._impl import (
     authorization_ApiKeyRid as ApiKeyRid,
     authorization_AuthorizationRequest as AuthorizationRequest,
     authorization_AuthorizationService as AuthorizationService,
+    authorization_Claim as Claim,
+    authorization_ClaimVisitor as ClaimVisitor,
     authorization_CreateApiKeyRequest as CreateApiKeyRequest,
     authorization_CreateApiKeyResponse as CreateApiKeyResponse,
     authorization_GetAccessTokenFromApiKeyRequest as GetAccessTokenFromApiKeyRequest,
@@ -15,6 +17,25 @@ from .._impl import (
     authorization_ListApiKeyRequest as ListApiKeyRequest,
     authorization_ListApiKeyResponse as ListApiKeyResponse,
     authorization_RegisterInWorkspaceRequest as RegisterInWorkspaceRequest,
-    authorization_RegistrationRequest as RegistrationRequest,
 )
 
+__all__ = [
+    'ApiKey',
+    'ApiKeyRid',
+    'AuthorizationRequest',
+    'Claim',
+    'ClaimVisitor',
+    'CreateApiKeyRequest',
+    'CreateApiKeyResponse',
+    'GetAccessTokenFromApiKeyRequest',
+    'GetAccessTokenRequest',
+    'GetAccessTokenResponse',
+    'IsEmailAllowedRequest',
+    'IsEmailAllowedResponse',
+    'ListApiKeyRequest',
+    'ListApiKeyResponse',
+    'RegisterInWorkspaceRequest',
+    'AuthorizationService',
+    'InternalApiKeyService',
+]
+
