@@ -40,6 +40,8 @@ from .._impl import (
     module_SemanticVersion as SemanticVersion,
     module_UnapplyModuleRequest as UnapplyModuleRequest,
     module_UnapplyModuleResponse as UnapplyModuleResponse,
+    module_UpdateModuleApplicationRequest as UpdateModuleApplicationRequest,
+    module_UpdateModuleApplicationResponse as UpdateModuleApplicationResponse,
     module_UpdateModuleRequest as UpdateModuleRequest,
     module_ValueType as ValueType,
     module_VariableName as VariableName,
@@ -85,6 +87,8 @@ __all__ = [
     'SemanticVersion',
     'UnapplyModuleRequest',
     'UnapplyModuleResponse',
+    'UpdateModuleApplicationRequest',
+    'UpdateModuleApplicationResponse',
     'UpdateModuleRequest',
     'ValueType',
     'VariableName',
