@@ -15,38 +15,30 @@ from .._impl import (
     scout_catalog_DatasetFile as DatasetFile,
     scout_catalog_DatasetFileUri as DatasetFileUri,
     scout_catalog_DatasetFilesPage as DatasetFilesPage,
-    scout_catalog_DatasetFilter as DatasetFilter,
     scout_catalog_DatasetOriginMetadata as DatasetOriginMetadata,
-    scout_catalog_DeleteSeriesResult as DeleteSeriesResult,
     scout_catalog_EnrichedDataset as EnrichedDataset,
     scout_catalog_EpochTimestamp as EpochTimestamp,
     scout_catalog_GetChannelsForDatasetsRequest as GetChannelsForDatasetsRequest,
     scout_catalog_GetDatasetsRequest as GetDatasetsRequest,
     scout_catalog_GetDetailsForChannelsRequest as GetDetailsForChannelsRequest,
     scout_catalog_GetHandlesForDatasetsRequest as GetHandlesForDatasetsRequest,
-    scout_catalog_GetSeriesDetailsByName as GetSeriesDetailsByName,
-    scout_catalog_GetSeriesDetailsByRid as GetSeriesDetailsByRid,
-    scout_catalog_GetSeriesDetailsRequest as GetSeriesDetailsRequest,
-    scout_catalog_GetSeriesDetailsRequestVisitor as GetSeriesDetailsRequestVisitor,
     scout_catalog_Handle as Handle,
     scout_catalog_HandleVisitor as HandleVisitor,
     scout_catalog_IngestProgressV2 as IngestProgressV2,
     scout_catalog_IngestStatus as IngestStatus,
+    scout_catalog_IngestTagMetadata as IngestTagMetadata,
     scout_catalog_Iso8601Timestamp as Iso8601Timestamp,
-    scout_catalog_ListDatasetsRequest as ListDatasetsRequest,
     scout_catalog_MarkFileIngestError as MarkFileIngestError,
     scout_catalog_MarkFileIngestSuccessful as MarkFileIngestSuccessful,
+    scout_catalog_OriginFileUri as OriginFileUri,
     scout_catalog_RelativeTimestamp as RelativeTimestamp,
     scout_catalog_RetentionPolicy as RetentionPolicy,
     scout_catalog_RetentionPolicyType as RetentionPolicyType,
     scout_catalog_S3Handle as S3Handle,
-    scout_catalog_SearchDatasetsByTextRequest as SearchDatasetsByTextRequest,
-    scout_catalog_SearchDatasetsByTextResponse as SearchDatasetsByTextResponse,
     scout_catalog_SearchDatasetsQuery as SearchDatasetsQuery,
     scout_catalog_SearchDatasetsQueryVisitor as SearchDatasetsQueryVisitor,
     scout_catalog_SearchDatasetsRequest as SearchDatasetsRequest,
     scout_catalog_SearchDatasetsResponse as SearchDatasetsResponse,
-    scout_catalog_SeriesDetails as SeriesDetails,
     scout_catalog_SkipRowsConfig as SkipRowsConfig,
     scout_catalog_SortField as SortField,
     scout_catalog_SortOptions as SortOptions,
@@ -61,3 +53,57 @@ from .._impl import (
     scout_catalog_WeakTimestampType as WeakTimestampType,
 )
 
+__all__ = [
+    'AbsoluteTimestamp',
+    'AbsoluteTimestampVisitor',
+    'AddFileToDataset',
+    'AllPropertiesAndLabelsResponse',
+    'Bounds',
+    'Channel',
+    'ChannelConfig',
+    'ChannelDetails',
+    'CreateDataset',
+    'CustomTimestamp',
+    'Dataset',
+    'DatasetFile',
+    'DatasetFileUri',
+    'DatasetFilesPage',
+    'DatasetOriginMetadata',
+    'EnrichedDataset',
+    'EpochTimestamp',
+    'GetChannelsForDatasetsRequest',
+    'GetDatasetsRequest',
+    'GetDetailsForChannelsRequest',
+    'GetHandlesForDatasetsRequest',
+    'Handle',
+    'HandleVisitor',
+    'IngestProgressV2',
+    'IngestStatus',
+    'IngestTagMetadata',
+    'Iso8601Timestamp',
+    'MarkFileIngestError',
+    'MarkFileIngestSuccessful',
+    'OriginFileUri',
+    'RelativeTimestamp',
+    'RetentionPolicy',
+    'RetentionPolicyType',
+    'S3Handle',
+    'SearchDatasetsQuery',
+    'SearchDatasetsQueryVisitor',
+    'SearchDatasetsRequest',
+    'SearchDatasetsResponse',
+    'SkipRowsConfig',
+    'SortField',
+    'SortOptions',
+    'TimestampMetadata',
+    'TimestampType',
+    'TimestampTypeVisitor',
+    'UnitConfig',
+    'UpdateBoundsRequest',
+    'UpdateDatasetMetadata',
+    'UpdateIngestStatus',
+    'UpdateIngestStatusV2',
+    'WeakTimestampType',
+    'CatalogService',
+]
+
