@@ -9,6 +9,10 @@ from .._impl import (
     scout_compute_api_ApproximateThresholdOperator as ApproximateThresholdOperator,
     scout_compute_api_ApproximateThresholdRanges as ApproximateThresholdRanges,
     scout_compute_api_ArithmeticSeries as ArithmeticSeries,
+    scout_compute_api_ArraySeries as ArraySeries,
+    scout_compute_api_ArraySeriesVisitor as ArraySeriesVisitor,
+    scout_compute_api_ArrowArrayPlot as ArrowArrayPlot,
+    scout_compute_api_ArrowArrayPlotVisitor as ArrowArrayPlotVisitor,
     scout_compute_api_ArrowBucketedEnumPlot as ArrowBucketedEnumPlot,
     scout_compute_api_ArrowBucketedNumericPlot as ArrowBucketedNumericPlot,
     scout_compute_api_ArrowEnumPlot as ArrowEnumPlot,
@@ -34,9 +38,11 @@ from .._impl import (
     scout_compute_api_BitXorFunction as BitXorFunction,
     scout_compute_api_BucketedCartesian3dPlot as BucketedCartesian3dPlot,
     scout_compute_api_BucketedCartesianPlot as BucketedCartesianPlot,
+    scout_compute_api_BucketedEnumArrayPlot as BucketedEnumArrayPlot,
     scout_compute_api_BucketedEnumPlot as BucketedEnumPlot,
     scout_compute_api_BucketedGeoPlot as BucketedGeoPlot,
     scout_compute_api_BucketedGeoPlotVisitor as BucketedGeoPlotVisitor,
+    scout_compute_api_BucketedNumericArrayPlot as BucketedNumericArrayPlot,
     scout_compute_api_BucketedNumericPlot as BucketedNumericPlot,
     scout_compute_api_Cartesian as Cartesian,
     scout_compute_api_Cartesian3d as Cartesian3d,
@@ -89,6 +95,8 @@ from .._impl import (
     scout_compute_api_DecimateWithBuckets as DecimateWithBuckets,
     scout_compute_api_DecimateWithResolution as DecimateWithResolution,
     scout_compute_api_DerivativeSeries as DerivativeSeries,
+    scout_compute_api_DerivedSeries as DerivedSeries,
+    scout_compute_api_DerivedSeriesVisitor as DerivedSeriesVisitor,
     scout_compute_api_DoubleConstant as DoubleConstant,
     scout_compute_api_DoubleConstantVisitor as DoubleConstantVisitor,
     scout_compute_api_DriverSeries3d as DriverSeries3d,
@@ -185,6 +193,7 @@ from .._impl import (
     scout_compute_api_MinMaxThresholdRanges as MinMaxThresholdRanges,
     scout_compute_api_MinSeries as MinSeries,
     scout_compute_api_Minimum as Minimum,
+    scout_compute_api_ModuleApplicationDerivedSeries as ModuleApplicationDerivedSeries,
     scout_compute_api_NegativeValueConfiguration as NegativeValueConfiguration,
     scout_compute_api_NegativeValueConfigurationVisitor as NegativeValueConfigurationVisitor,
     scout_compute_api_NotRanges as NotRanges,
@@ -220,7 +229,9 @@ from .._impl import (
     scout_compute_api_PageStrategyVisitor as PageStrategyVisitor,
     scout_compute_api_PageToken as PageToken,
     scout_compute_api_PageTokenVisitor as PageTokenVisitor,
+    scout_compute_api_PagedEnumArrayPlot as PagedEnumArrayPlot,
     scout_compute_api_PagedLogPlot as PagedLogPlot,
+    scout_compute_api_PagedNumericArrayPlot as PagedNumericArrayPlot,
     scout_compute_api_ParameterInput as ParameterInput,
     scout_compute_api_ParameterizedComputeNodeRequest as ParameterizedComputeNodeRequest,
     scout_compute_api_ParameterizedComputeNodeResponse as ParameterizedComputeNodeResponse,
@@ -339,6 +350,10 @@ __all__ = [
     'ApproximateThresholdOperator',
     'ApproximateThresholdRanges',
     'ArithmeticSeries',
+    'ArraySeries',
+    'ArraySeriesVisitor',
+    'ArrowArrayPlot',
+    'ArrowArrayPlotVisitor',
     'ArrowBucketedEnumPlot',
     'ArrowBucketedNumericPlot',
     'ArrowEnumPlot',
@@ -364,9 +379,11 @@ __all__ = [
     'BitXorFunction',
     'BucketedCartesian3dPlot',
     'BucketedCartesianPlot',
+    'BucketedEnumArrayPlot',
     'BucketedEnumPlot',
     'BucketedGeoPlot',
     'BucketedGeoPlotVisitor',
+    'BucketedNumericArrayPlot',
     'BucketedNumericPlot',
     'Cartesian',
     'CartesianVisitor',
@@ -418,6 +435,8 @@ __all__ = [
     'DecimateWithBuckets',
     'DecimateWithResolution',
     'DerivativeSeries',
+    'DerivedSeries',
+    'DerivedSeriesVisitor',
     'DoubleConstant',
     'DoubleConstantVisitor',
     'DriverSeries3d',
@@ -514,6 +533,7 @@ __all__ = [
     'MinMaxThresholdRanges',
     'MinSeries',
     'Minimum',
+    'ModuleApplicationDerivedSeries',
     'NegativeValueConfiguration',
     'NegativeValueConfigurationVisitor',
     'NotRanges',
@@ -549,7 +569,9 @@ __all__ = [
     'PageStrategyVisitor',
     'PageToken',
     'PageTokenVisitor',
+    'PagedEnumArrayPlot',
     'PagedLogPlot',
+    'PagedNumericArrayPlot',
     'ParameterInput',
     'ParameterizedComputeNodeRequest',
     'ParameterizedComputeNodeResponse',
