@@ -5,6 +5,8 @@ from .._impl import (
     scout_compute_resolved_api_AggregateEnumSeriesNode as AggregateEnumSeriesNode,
     scout_compute_resolved_api_AggregateNumericSeriesNode as AggregateNumericSeriesNode,
     scout_compute_resolved_api_ArithmeticSeriesNode as ArithmeticSeriesNode,
+    scout_compute_resolved_api_ArraySeriesNode as ArraySeriesNode,
+    scout_compute_resolved_api_ArraySeriesNodeVisitor as ArraySeriesNodeVisitor,
     scout_compute_resolved_api_BandPassConfiguration as BandPassConfiguration,
     scout_compute_resolved_api_BandStopConfiguration as BandStopConfiguration,
     scout_compute_resolved_api_BinaryArithmeticSeriesNode as BinaryArithmeticSeriesNode,
@@ -160,6 +162,8 @@ __all__ = [
     'AggregateEnumSeriesNode',
     'AggregateNumericSeriesNode',
     'ArithmeticSeriesNode',
+    'ArraySeriesNode',
+    'ArraySeriesNodeVisitor',
     'BandPassConfiguration',
     'BandStopConfiguration',
     'BinaryArithmeticSeriesNode',
